#include <string>
#include <string_view>
#include <vector>

struct my_string : public std::string
{
	__declspec(noinline)
		my_string::my_string( const std::string_view& str ) :
		std::string( str.data(), str.size() )
	{}

	template <typename T>
	my_string& arg( T )
	{
		return *this;
	}
};

struct my_string_view : public std::string_view
{
	my_string_view( const std::string_view::value_type* val ) :
		std::string_view( val ) {}

	template <typename... PARAMS>
	my_string arg( PARAMS&&... prms ) {
		return my_string( *this ).arg( std::forward<PARAMS>( prms )... );
	}
};

template <typename T>
struct basic_color
{
	T r, g, b, a;

	basic_color() : r( 0 ), g( 0 ), b( 0 ), a( 255 ) {}

	template <typename U>
	explicit basic_color( const basic_color<U>& c ) :
		r( c.r ), g( c.g ), b( c.b ), a( c.a )
	{}
};

using color = basic_color<std::uint8_t>;
using float_color = basic_color<float>;

__declspec(noinline)
void change_float_color( float_color& color )
{
	color.r = 0.1f;
}

int main()
{
	std::vector<float_color> colors = { {} };
	float sum = 0;
	for ( std::uint32_t i = 0; i < 1; ++i )
	{
		float_color fc;
		change_float_color( fc );
		color c( fc );
		std::vector<std::string> msgs;
		msgs.push_back( my_string_view( "" ).arg( c.r ) );
		msgs.push_back( my_string_view( "" ).arg( c.g ) );
		sum += fc.b - colors[i].b;
	}
	return static_cast<int>(sqrt( sum ));
}
